import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { User } from "./User.ts"

export const ActivityReply = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the reply */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the replies creator */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The id of the parent activity */
  withActivityId() {
    query[0] = query[0].set({ subField: "activityId", level })
    return this
  },
  /** The reply text */
  withText(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "text", level, variables: args })
    return this
  },
  /** The amount of likes the reply has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the reply */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** The time the reply was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The user who created reply */
  withUser(fn: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the reply */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
