import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { ActivityReply } from "./ActivityReply.ts"
import { Media } from "./Media.ts"
import { User } from "./User.ts"

export const TextActivity = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the activity */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The user id of the activity's creator */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of activity */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The number of activity replies */
  withReplyCount() {
    query[0] = query[0].set({ subField: "replyCount", level })
    return this
  },
  /** The status text (Markdown) */
  withText(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "text", level, variables: args })
    return this
  },
  /** The url for the activity page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** If the activity is locked and can receive replies */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
  /** If the currently authenticated user is subscribed to the activity */
  withIsSubscribed() {
    query[0] = query[0].set({ subField: "isSubscribed", level })
    return this
  },
  /** The amount of likes the activity has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the activity */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** If the activity is pinned to the top of the users activity feed */
  withIsPinned() {
    query[0] = query[0].set({ subField: "isPinned", level })
    return this
  },
  /** The time the activity was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The user who created the activity */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The written replies to the activity */
  withReplies(fn?: Fn<typeof ActivityReply>) {
    query[0] = query[0].set({ subField: "replies", level })
    let tmpQuery
    if (fn) fn(ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the activity */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

export const ListActivity = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the activity */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The user id of the activity's creator */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of activity */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The number of activity replies */
  withReplyCount() {
    query[0] = query[0].set({ subField: "replyCount", level })
    return this
  },
  /** The list item's textual status */
  withStatus() {
    query[0] = query[0].set({ subField: "status", level })
    return this
  },
  /** The list progress made */
  withProgress() {
    query[0] = query[0].set({ subField: "progress", level })
    return this
  },
  /** If the activity is locked and can receive replies */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
  /** If the currently authenticated user is subscribed to the activity */
  withIsSubscribed() {
    query[0] = query[0].set({ subField: "isSubscribed", level })
    return this
  },
  /** The amount of likes the activity has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the activity */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** If the activity is pinned to the top of the users activity feed */
  withIsPinned() {
    query[0] = query[0].set({ subField: "isPinned", level })
    return this
  },
  /** The url for the activity page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** The time the activity was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The owner of the activity */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The associated media to the activity update */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The written replies to the activity */
  withReplies(fn?: Fn<typeof ActivityReply>) {
    query[0] = query[0].set({ subField: "replies", level })
    let tmpQuery
    if (fn) fn(ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the activity */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

export const MessageActivity = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the activity */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The user id of the activity's recipient */
  withRecipientId() {
    query[0] = query[0].set({ subField: "recipientId", level })
    return this
  },
  /** The user id of the activity's sender */
  withMessengerId() {
    query[0] = query[0].set({ subField: "messengerId", level })
    return this
  },
  /** The type of the activity */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The number of activity replies */
  withReplyCount() {
    query[0] = query[0].set({ subField: "replyCount", level })
    return this
  },
  /** The message text (Markdown) */
  withMessage(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "message", level, variables: args })
    return this
  },
  /** If the activity is locked and can receive replies */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
  /** If the currently authenticated user is subscribed to the activity */
  withIsSubscribed() {
    query[0] = query[0].set({ subField: "isSubscribed", level })
    return this
  },
  /** The amount of likes the activity has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the activity */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** If the message is private and only viewable to the sender and recipients */
  withIsPrivate() {
    query[0] = query[0].set({ subField: "isPrivate", level })
    return this
  },
  /** The url for the activity page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** The time the activity was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The user who the activity message was sent to */
  withRecipient(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "recipient", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who sent the activity message */
  withMessenger(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "messenger", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The written replies to the activity */
  withReplies(fn?: Fn<typeof ActivityReply>) {
    query[0] = query[0].set({ subField: "replies", level })
    let tmpQuery
    if (fn) fn(ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the activity */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

export const ActivityUnion = ({ query, level }: Fields<UpdateOperation>) => ({
  withTextActivity(fn?: Fn<typeof TextActivity>) {
    query[0] = query[0].set({ subField: "TextActivity", level, hasSubField: true, isUnion: true })
    let tmpQuery
    if (fn) fn(TextActivity({ query: tmpQuery = [query[0]], level: level + 1 }))
    else TextActivity({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withListActivity(fn?: Fn<typeof ListActivity>) {
    query[0] = query[0].set({ subField: "ListActivity", level, hasSubField: true, isUnion: true })
    let tmpQuery
    if (fn) fn(ListActivity({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ListActivity({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withMessageActivity(fn?: Fn<typeof MessageActivity>) {
    query[0] = query[0].set({
      subField: "MessageActivity",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(MessageActivity({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MessageActivity({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
