import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { PageInfo } from "./Page.ts"

const AiringScheduleEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn: Fn<typeof AiringSchedule>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    fn(AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The id of the connection */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
})

export const AiringScheduleConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn: Fn<typeof AiringScheduleEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    fn(AiringScheduleEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn: Fn<typeof AiringSchedule>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    fn(AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const AiringSchedule = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the airing schedule item */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The time the episode airs at */
  withAiringAt() {
    query[0] = query[0].set({ subField: "airingAt", level })
    return this
  },
  /** Seconds until episode starts airing */
  withTimeUntilAiring() {
    query[0] = query[0].set({ subField: "timeUntilAiring", level })
    return this
  },
  /** The airing episode number */
  withEpisode() {
    query[0] = query[0].set({ subField: "episode", level })
    return this
  },
  /** The associate media id of the airing episode */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  /** The associate media of the airing episode */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
