import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { AtLeastOne } from "../types/AtLeastOne.ts"
import {
  FavouritesAnimeArgs,
  FavouritesCharactersArgs,
  FavouritesMangaArgs,
  FavouritesStaffArgs,
  FavouritesStudiosArgs,
} from "../types/generated/graphql.ts"
import { CharacterConnection } from "./Character.ts"
import { MediaConnection } from "./Media.ts"
import { StaffConnection } from "./Staff.ts"
import { StudioConnection } from "./Studio.ts"

export const Favourites = ({ query, level }: Fields<UpdateOperation>) => ({
  /** Favourite anime */
  withAnime(op: { args?: AtLeastOne<FavouritesAnimeArgs>; fn: Fn<typeof MediaConnection> }) {
    query[0] = query[0].set({ subField: "anime", level, variables: op?.args })
    let tmpQuery
    op.fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Favourite manga */
  withManga(op: { args?: AtLeastOne<FavouritesMangaArgs>; fn: Fn<typeof MediaConnection> }) {
    query[0] = query[0].set({ subField: "manga", level, variables: op?.args })
    let tmpQuery
    op.fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Favourite characters */
  withCharacters(
    op: { args?: AtLeastOne<FavouritesCharactersArgs>; fn: Fn<typeof CharacterConnection> },
  ) {
    query[0] = query[0].set({ subField: "characters", level, variables: op?.args })
    let tmpQuery
    op.fn(CharacterConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Favourite staff */
  withStaff(op: { args?: AtLeastOne<FavouritesStaffArgs>; fn: Fn<typeof StaffConnection> }) {
    query[0] = query[0].set({ subField: "staff", level, variables: op?.args })
    let tmpQuery
    op.fn(StaffConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Favourite studios */
  withStudios(op: { args?: AtLeastOne<FavouritesStudiosArgs>; fn: Fn<typeof StudioConnection> }) {
    query[0] = query[0].set({ subField: "studios", level, variables: op?.args })
    let tmpQuery
    op.fn(StudioConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})
