import {
  MediaAiringScheduleArgs,
  MediaCharactersArgs,
  MediaDescriptionArgs,
  MediaEdgeRelationTypeArgs,
  MediaEdgeVoiceActorRolesArgs,
  MediaEdgeVoiceActorsArgs,
  MediaRecommendationsArgs,
  MediaReviewsArgs,
  MediaSourceArgs,
  MediaStaffArgs,
  MediaStatusArgs,
  MediaStudiosArgs,
  MediaTrendsArgs,
} from "../types/generated/graphql.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import type { AtLeastOne } from "../types/AtLeastOne.ts"
import { PageInfo } from "./Page.ts"
import { FuzzyDate } from "../anilist.ts"
import { MediaTag } from "./MediaTag.ts"
import { MediaList } from "./MediaList.ts"
import { AiringSchedule, AiringScheduleConnection } from "./AiringSchedule.ts"
import { Character, CharacterConnection } from "./Character.ts"
import { Staff, StaffConnection, StaffRoleType } from "./Staff.ts"
import { MediaTrendConnection } from "./MediaTrend.ts"
import { RecommendationConnection } from "./Recommendation.ts"
import { ReviewConnection } from "./Review.ts"
import { StudioConnection } from "./Studio.ts"

export const MediaListGroup = ({ query, level }: Fields<UpdateOperation>) => ({
  /** Media list entries */
  withEntries(fn: Fn<typeof MediaList>) {
    query[0] = query[0].set({ subField: "entries", level, hasSubField: true })
    let tmpQuery
    fn(MediaList({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withName() {
    query[0] = query[0].set({ subField: "name", level })
    return this
  },
  withIsCustomList() {
    query[0] = query[0].set({ subField: "isCustomList", level })
    return this
  },
  withIsSplitCompletedList() {
    query[0] = query[0].set({ subField: "isSplitCompletedList", level })
    return this
  },
  withStatus() {
    query[0] = query[0].set({ subField: "status", level })
    return this
  },
})

const MediaTitle = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The romanization of the native language title */
  romaji(args?: { stylised: boolean }) {
    query[0] = query[0].set({ subField: "romaji", level, variables: args })
    return this
  },
  /** The official english title */
  english(args?: { stylised: boolean }) {
    query[0] = query[0].set({ subField: "english", level, variables: args })
    return this
  },
  /** Official title in it's native language */
  native(args?: { stylised: boolean }) {
    query[0] = query[0].set({ subField: "native", level, variables: args })
    return this
  },
  /** The currently authenticated users preferred title language. Default romaji for non-authenticated */
  userPreferred() {
    query[0] = query[0].set({ subField: "userPreferred", level })
    return this
  },
})

const MediaTrailer = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The trailer video id */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The site the video is hosted by (Currently either youtube or dailymotion) */
  withSite() {
    query[0] = query[0].set({ subField: "site", level })
    return this
  },
  /** The url for the thumbnail image of the video */
  withThumbnail() {
    query[0] = query[0].set({ subField: "thumbnail", level })
    return this
  },
})

const MediaCoverImage = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The cover image url of the media at its largest size. If this size isn't available, large will be provided instead. */
  withExtraLarge() {
    query[0] = query[0].set({ subField: "extraLarge", level })
    return this
  },
  /** The cover image url of the media at a large size */
  withLarge() {
    query[0] = query[0].set({ subField: "large", level })
    return this
  },
  /** The cover image url of the media at medium size */
  withMedium() {
    query[0] = query[0].set({ subField: "medium", level })
    return this
  },
  /** Average #hex color of cover image */
  withColor() {
    query[0] = query[0].set({ subField: "color", level })
    return this
  },
})

const MediaExternalLink = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the external link */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The url of the external link or base url of link source */
  withUrl() {
    query[0] = query[0].set({ subField: "url", level })
    return this
  },
  /** The links website site name */
  withSite() {
    query[0] = query[0].set({ subField: "site", level })
    return this
  },
  /** The links website site id */
  withSiteId() {
    query[0] = query[0].set({ subField: "siteId", level })
    return this
  },
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** Language the site content is in. See Staff language field for values. */
  withLanguage() {
    query[0] = query[0].set({ subField: "language", level })
    return this
  },
  withColor() {
    query[0] = query[0].set({ subField: "color", level })
    return this
  },
  /** The icon image url of the site. Not available for all links. Transparent PNG 64x64 */
  withIcon() {
    query[0] = query[0].set({ subField: "icon", level })
    return this
  },
  withNotes() {
    query[0] = query[0].set({ subField: "notes", level })
    return this
  },
  withIsDisabled() {
    query[0] = query[0].set({ subField: "isDisabled", level })
    return this
  },
})

const MediaStreamingEpisode = ({ query, level }: Fields<UpdateOperation>) => ({
  /** Title of the episode */
  withTitle() {
    query[0] = query[0].set({ subField: "title", level })
    return this
  },
  /** Url of episode image thumbnail */
  withThumbnail() {
    query[0] = query[0].set({ subField: "thumbnail", level })
    return this
  },
  /** The url of the episode */
  withUrl() {
    query[0] = query[0].set({ subField: "url", level })
    return this
  },
  /** The site location of the streaming episodes */
  withSite() {
    query[0] = query[0].set({ subField: "site", level })
    return this
  },
})

const MediaRank = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the rank */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The numerical rank of the media */
  withRank() {
    query[0] = query[0].set({ subField: "rank", level })
    return this
  },
  /** The type of ranking */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The format the media is ranked within */
  withFormat() {
    query[0] = query[0].set({ subField: "format", level })
    return this
  },
  /** The year the media is ranked within */
  withYear() {
    query[0] = query[0].set({ subField: "year", level })
    return this
  },
  /** The season the media is ranked within */
  withSeason() {
    query[0] = query[0].set({ subField: "season", level })
    return this
  },
  /** If the ranking is based on all time instead of a season/year */
  withAllTime() {
    query[0] = query[0].set({ subField: "allTime", level })
    return this
  },
  /** String that gives context to the ranking type and time span */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
})

const MediaStats = ({ query, level }: Fields<UpdateOperation>) => ({
  scoreDistribution(fn: Fn<typeof ScoreDistribution>) {
    query[0] = query[0].set({ subField: "scoreDistribution", level, hasSubField: true })
    let tmpQuery
    fn(ScoreDistribution({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  statusDistribution(fn: Fn<typeof StatusDistribution>) {
    query[0] = query[0].set({ subField: "statusDistribution", level, hasSubField: true })
    let tmpQuery
    fn(StatusDistribution({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

const StatusDistribution = ({ query, level }: Fields<UpdateOperation>) => ({
  withStatus() {
    query[0] = query[0].set({ subField: "status", level })
    return this
  },
  withAmount() {
    query[0] = query[0].set({ subField: "amount", level })
    return this
  },
})

const ScoreDistribution = ({ query, level }: Fields<UpdateOperation>) => ({
  withScore() {
    query[0] = query[0].set({ subField: "score", level })
    return this
  },
  withAmount() {
    query[0] = query[0].set({ subField: "amount", level })
    return this
  },
})

const MediaEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The id of the connection */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of relation to the parent model */
  withRelationType(args?: AtLeastOne<MediaEdgeRelationTypeArgs>) {
    query[0] = query[0].set({ subField: "relationType", level, variables: args })
    return this
  },
  /** If the studio is the main animation studio of the media (For Studio->MediaConnection field only) */
  withIsMainStudio() {
    query[0] = query[0].set({ subField: "isMainStudio", level })
    return this
  },
  /** The characters in the media voiced by the parent actor */
  withCharacters(fn: Fn<typeof Character>) {
    query[0] = query[0].set({ subField: "characters", level, hasSubField: true })
    let tmpQuery
    fn(Character({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The characters role in the media */
  withCharacterRole() {
    query[0] = query[0].set({ subField: "characterRole", level })
    return this
  },
  /** Media specific character name */
  withCharacterName() {
    query[0] = query[0].set({ subField: "characterName", level })
    return this
  },
  /** Notes regarding the VA's role for the character */
  withRoleNotes() {
    query[0] = query[0].set({ subField: "roleNotes", level })
    return this
  },
  /** Used for grouping roles where multiple dubs exist for the same language. Either dubbing company name or language variant. */
  withDubGroup() {
    query[0] = query[0].set({ subField: "dubGroup", level })
    return this
  },
  /** The role of the staff member in the production of the media */
  withStaffRole() {
    query[0] = query[0].set({ subField: "staffRole", level })
    return this
  },
  /** The voice actors of the character */
  withVoiceActors(op?: { args?: AtLeastOne<MediaEdgeVoiceActorsArgs>; fn?: Fn<typeof Staff> }) {
    query[0] = query[0].set({
      subField: "voiceActors",
      level,
      variables: op?.args,
      hasSubField: true,
    })
    let tmpQuery
    if (op?.fn) op.fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Staff({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The voice actors of the character with role date */
  withVoiceActorRoles(op: {
    args?: AtLeastOne<MediaEdgeVoiceActorRolesArgs>
    fn: Fn<typeof StaffRoleType>
  }) {
    query[0] = query[0].set({
      subField: "voiceActorRoles",
      level,
      variables: op.args,
      hasSubField: true,
    })
    let tmpQuery
    op.fn(StaffRoleType({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The order the media should be displayed from the users favourites */
  withFavouriteOrder() {
    query[0] = query[0].set({ subField: "favouriteOrder", level })
    return this
  },
})

export const MediaConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn?: Fn<typeof MediaEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaEdge({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const Media = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the media */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The mal id of the media */
  withIdMal() {
    query[0] = query[0].set({ subField: "idMal", level })
    return this
  },
  /** The type of the media; anime or manga */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The format the media was released in */
  withFormat() {
    query[0] = query[0].set({ subField: "format", level })
    return this
  },
  /** The season the media was initially released in */
  withSeason() {
    query[0] = query[0].set({ subField: "season", level })
    return this
  },
  /** The season year the media was initially released in */
  withSeasonYear() {
    query[0] = query[0].set({ subField: "seasonYear", level })
    return this
  },
  /** The year & season the media was initially released in */
  withSeasonInt() {
    query[0] = query[0].set({ subField: "seasonInt", level })
    return this
  },
  /** The amount of episodes the anime has when complete */
  withEpisodes() {
    query[0] = query[0].set({ subField: "episodes", level })
    return this
  },
  /** The general length of each anime episode in minutes */
  withDuration() {
    query[0] = query[0].set({ subField: "duration", level })
    return this
  },
  /** The amount of chapters the manga has when complete */
  withChapters() {
    query[0] = query[0].set({ subField: "chapters", level })
    return this
  },
  /** The amount of volumes the manga has when complete */
  withVolumes() {
    query[0] = query[0].set({ subField: "volumes", level })
    return this
  },
  /** Where the media was created. (ISO 3166-1 alpha-2) */
  withCountryOfOrigin() {
    query[0] = query[0].set({ subField: "countryOfOrigin", level })
    return this
  },
  /** If the media is officially licensed or a self-published doujin release */
  withIsLicensed() {
    query[0] = query[0].set({ subField: "isLicensed", level })
    return this
  },
  /** Official Twitter hashtags for the media */
  withHashtag() {
    query[0] = query[0].set({ subField: "hashtag", level })
    return this
  },
  /** When the media's data was last updated */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
  /** The banner image of the media */
  withBannerImage() {
    query[0] = query[0].set({ subField: "bannerImage", level })
    return this
  },
  /** The genres of the media */
  withGenres() {
    query[0] = query[0].set({ subField: "genres", level })
    return this
  },
  /** Alternative titles of the media */
  withSynonyms() {
    query[0] = query[0].set({ subField: "synonyms", level })
    return this
  },
  /** A weighted average score of all the user's scores of the media */
  withAverageScore() {
    query[0] = query[0].set({ subField: "averageScore", level })
    return this
  },
  /** Mean score of all the user's scores of the media */
  withMeanScore() {
    query[0] = query[0].set({ subField: "meanScore", level })
    return this
  },
  /** The number of users with the media on their list */
  withPopularity() {
    query[0] = query[0].set({ subField: "popularity", level })
    return this
  },
  /** Locked media may not be added to lists our favorited. This may be due to the entry pending for deletion or other reasons. */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
  /** The amount of related activity in the past hour */
  withTrending() {
    query[0] = query[0].set({ subField: "trending", level })
    return this
  },
  /** The amount of user's who have favourited the media */
  withFavourites() {
    query[0] = query[0].set({ subField: "favourites", level })
    return this
  },
  /** If the media is marked as favourite by the current authenticated user */
  withIsFavourite() {
    query[0] = query[0].set({ subField: "isFavourite", level })
    return this
  },
  /** If the media is blocked from being added to favourites */
  withIsFavouriteBlocked() {
    query[0] = query[0].set({ subField: "isFavouriteBlocked", level })
    return this
  },
  /** If the media is intended only for 18+ adult audiences */
  withIsAdult() {
    query[0] = query[0].set({ subField: "isAdult", level })
    return this
  },
  /** The media's next episode airing schedule */
  withNextAiringEpisode(fn?: Fn<typeof AiringSchedule>) {
    query[0] = query[0].set({ subField: "nextAiringEpisode", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }))
    else AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The url for the media page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** If the media should have forum thread automatically created for it on airing episode release */
  withAutoCreateForumThread() {
    query[0] = query[0].set({ subField: "autoCreateForumThread", level })
    return this
  },
  /** If the media is blocked from being recommended to/from */
  withIsRecommendationBlocked() {
    query[0] = query[0].set({ subField: "isRecommendationBlocked", level })
    return this
  },
  /** If the media is blocked from being reviewed */
  withIsReviewBlocked() {
    query[0] = query[0].set({ subField: "isReviewBlocked", level })
    return this
  },
  /** Notes for site moderators */
  withModNotes() {
    query[0] = query[0].set({ subField: "modNotes", level })
    return this
  },
  /** The current releasing status of the media */
  withStatus(args?: AtLeastOne<MediaStatusArgs>) {
    query[0] = query[0].set({ subField: "status", level, variables: args })
    return this
  },
  /** Short description of the media's story and characters */
  withDescription(args?: AtLeastOne<MediaDescriptionArgs>) {
    query[0] = query[0].set({ subField: "description", level, variables: args })
    return this
  },
  /** Source type the media was adapted from. */
  withSource(args?: AtLeastOne<MediaSourceArgs>) {
    query[0] = query[0].set({ subField: "source", level, variables: args })
    return this
  },
  /** The staff who produced the media */
  withStaff(op: { args?: AtLeastOne<MediaStaffArgs>; fn: Fn<typeof StaffConnection> }) {
    query[0] = query[0].set({ subField: "staff", level, variables: op?.args, hasSubField: true })
    let tmpQuery
    op.fn(StaffConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** User recommendations for similar media */
  withRecommendations(
    op: { args?: AtLeastOne<MediaRecommendationsArgs>; fn: Fn<typeof RecommendationConnection> },
  ) {
    query[0] = query[0].set({
      subField: "recommendations",
      level,
      variables: op?.args,
      hasSubField: true,
    })
    let tmpQuery
    op.fn(RecommendationConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The characters in the media */
  withCharacters(op: {
    args?: AtLeastOne<MediaCharactersArgs>
    fn: Fn<typeof CharacterConnection>
  }) {
    query[0] = query[0].set({
      subField: "characters",
      level,
      variables: op?.args,
      hasSubField: true,
    })
    let tmpQuery
    op.fn(CharacterConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The companies who produced the media */
  withStudios(op: {
    args?: AtLeastOne<MediaStudiosArgs>
    fn: Fn<typeof StudioConnection>
  }) {
    query[0] = query[0].set({ subField: "studios", level, variables: op?.args, hasSubField: true })
    let tmpQuery
    op.fn(StudioConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The media's entire airing schedule */
  withAiringSchedule(op: {
    args?: AtLeastOne<MediaAiringScheduleArgs>
    fn: Fn<typeof AiringScheduleConnection>
  }) {
    query[0] = query[0].set({
      subField: "airingSchedule",
      level,
      variables: op?.args,
      hasSubField: true,
    })
    let tmpQuery
    op.fn(AiringScheduleConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The media's daily trend stats */
  withTrends(op: { args?: AtLeastOne<MediaTrendsArgs>; fn: Fn<typeof MediaTrendConnection> }) {
    query[0] = query[0].set({ subField: "trends", level, variables: op?.args, hasSubField: true })
    let tmpQuery
    op.fn(MediaTrendConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** User reviews of the media */
  withReviews(op: { args?: AtLeastOne<MediaReviewsArgs>; fn: Fn<typeof ReviewConnection> }) {
    query[0] = query[0].set({ subField: "reviews", level, variables: op?.args, hasSubField: true })
    let tmpQuery
    op.fn(ReviewConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The official titles of the media in various languages */
  withTitle(fn: Fn<typeof MediaTitle>) {
    query[0] = query[0].set({ subField: "title", level, hasSubField: true })
    let tmpQuery
    fn(MediaTitle({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The first official release date of the media */
  withStartDate(fn?: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "startDate", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    else {
      FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 })
        .withYear()
        .withMonth()
        .withDay()
    }
    query[0] = tmpQuery[0]
    return this
  },
  /** The last official release date of the media */
  withEndDate(fn?: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "endDate", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    else {
      FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 })
        .withYear()
        .withMonth()
        .withDay()
    }
    query[0] = tmpQuery[0]
    return this
  },
  /** Media trailer or advertisement */
  withTrailer(fn: Fn<typeof MediaTrailer>) {
    query[0] = query[0].set({ subField: "trailer", level, hasSubField: true })
    let tmpQuery
    fn(MediaTrailer({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The cover images of the media */
  withCoverImage(fn?: Fn<typeof MediaCoverImage>) {
    query[0] = query[0].set({ subField: "coverImage", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaCoverImage({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaCoverImage({ query: tmpQuery = [query[0]], level: level + 1 }).withMedium()
    query[0] = tmpQuery[0]
    return this
  },
  /** List of tags that describes elements and themes of the media */
  withTags(fn: Fn<typeof MediaTag>) {
    query[0] = query[0].set({ subField: "tags", level, hasSubField: true })
    let tmpQuery
    fn(MediaTag({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Other media in the same or connecting franchise */
  withRelations(fn: Fn<typeof MediaConnection>) {
    query[0] = query[0].set({ subField: "relations", level, hasSubField: true })
    let tmpQuery
    fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** External links to another site related to the media */
  withExternalLinks(
    fn: Fn<typeof MediaExternalLink>,
  ) {
    query[0] = query[0].set({ subField: "externalLinks", level, hasSubField: true })
    let tmpQuery
    fn(MediaExternalLink({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Data and links to legal streaming episodes on external sites */
  withStreamingEpisodes(
    fn: Fn<typeof MediaStreamingEpisode>,
  ) {
    query[0] = query[0].set({ subField: "streamingEpisodes", level, hasSubField: true })
    let tmpQuery
    fn(MediaStreamingEpisode({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The ranking of the media in a particular time span and format compared to other media */
  withRankings(fn: Fn<typeof MediaRank>) {
    query[0] = query[0].set({ subField: "rankings", level, hasSubField: true })
    let tmpQuery
    fn(MediaRank({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The authenticated user's media list entry for the media */
  withMediaListEntry(fn?: Fn<typeof MediaList>) {
    query[0] = query[0].set({ subField: "mediaListEntry", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaList({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaList({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withStats(fn: Fn<typeof MediaStats>) {
    query[0] = query[0].set({ subField: "stats", level, hasSubField: true })
    let tmpQuery
    fn(MediaStats({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})
