import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { FuzzyDate } from "../anilist.ts"
import { User } from "./User.ts"

export const MediaListTypeOptions = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The order each list should be displayed in */
  withSectionOrder() {
    query[0] = query[0].set({ subField: "sectionOrder", level })
    return this
  },
  /** If the completed sections of the list should be separated by format */
  withSplitCompletedSectionByFormat() {
    query[0] = query[0].set({ subField: "splitCompletedSectionByFormat", level })
    return this
  },
  /** The names of the user's custom lists */
  withCustomLists() {
    query[0] = query[0].set({ subField: "customLists", level })
    return this
  },
  /** The names of the user's advanced scoring sections */
  withAdvancedScoring() {
    query[0] = query[0].set({ subField: "advancedScoring", level })
    return this
  },
  /** If advanced scoring is enabled */
  withAdvancedScoringEnabled() {
    query[0] = query[0].set({ subField: "advancedScoringEnabled", level })
    return this
  },
})

export const MediaListOptions = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The score format the user is using for media lists */
  withScoreFormat() {
    query[0] = query[0].set({ subField: "scoreFormat", level })
    return this
  },
  /** The default order list rows should be displayed in */
  withRowOrder() {
    query[0] = query[0].set({ subField: "rowOrder", level })
    return this
  },
  /** The user's anime list options */
  withAnimeList(fn: Fn<typeof MediaListTypeOptions>) {
    query[0] = query[0].set({ subField: "animeList", level })
    let tmpQuery
    fn(MediaListTypeOptions({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The user's manga list options */
  withMangaList(fn: Fn<typeof MediaListTypeOptions>) {
    query[0] = query[0].set({ subField: "mangaList", level })
    let tmpQuery
    fn(MediaListTypeOptions({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const MediaList = ({ query, level }: Fields<UpdateOperation>) => ({
  withCompletedAt(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({
      subField: "completedAt",
      level,
      hasSubField: true,
    })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withStartedAt(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({
      subField: "startedAt",
      level,
      hasSubField: true,
    })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  withStatus() {
    query[0] = query[0].set({ subField: "status", level })
    return this
  },
  withProgress() {
    query[0] = query[0].set({ subField: "progress", level })
    return this
  },
  withProgressVolumes() {
    query[0] = query[0].set({ subField: "progressVolumes", level })
    return this
  },
  withRepeat() {
    query[0] = query[0].set({ subField: "repeat", level })
    return this
  },
  withPriority() {
    query[0] = query[0].set({ subField: "priority", level })
    return this
  },
  withPrivate() {
    query[0] = query[0].set({ subField: "private", level })
    return this
  },
  withNotes() {
    query[0] = query[0].set({ subField: "notes", level })
    return this
  },
  withAdvancedScores() {
    query[0] = query[0].set({ subField: "advancedScores", level })
    return this
  },
  withHiddenFromStatusLists() {
    query[0] = query[0].set({ subField: "hiddenFromStatusLists", level })
    return this
  },
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
