import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { PageInfo } from "./Page.ts"

const MediaTrendEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn?: Fn<typeof MediaTrend>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }).withMediaId()
    query[0] = tmpQuery[0]
    return this
  },
})

export const MediaTrendConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn?: Fn<typeof MediaTrendEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaTrendEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaTrendEdge({ query: tmpQuery = [query[0]], level: level + 1 }).withNode()
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn?: Fn<typeof MediaTrend>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }).withMediaId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const MediaTrend = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the tag */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  /** The day the data was recorded (timestamp) */
  withDate() {
    query[0] = query[0].set({ subField: "date", level })
    return this
  },
  /** The amount of media activity on the day */
  withTrending() {
    query[0] = query[0].set({ subField: "trending", level })
    return this
  },
  /** A weighted average score of all the user's scores of the media */
  withAverageScore() {
    query[0] = query[0].set({ subField: "averageScore", level })
    return this
  },
  /** The number of users with the media on their list */
  withPopularity() {
    query[0] = query[0].set({ subField: "popularity", level })
    return this
  },
  /** The number of users with watching/reading the media */
  withInProgress() {
    query[0] = query[0].set({ subField: "inProgress", level })
    return this
  },
  /** If the media was being released at this time */
  withReleasing() {
    query[0] = query[0].set({ subField: "releasing", level })
    return this
  },
  /** The episode number of the anime released on this day */
  withEpisode() {
    query[0] = query[0].set({ subField: "episode", level })
    return this
  },
  /** The related media */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
