import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { ActivityUnion, MessageActivity } from "./ActivityUnion.ts"
import { Media } from "./Media.ts"
import { Thread } from "./Thread.ts"
import { ThreadComment } from "./ThreadComment.ts"
import { User } from "./User.ts"

const AiringNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the aired anime */
  withAnimeId() {
    query[0] = query[0].set({ subField: "animeId", level })
    return this
  },
  /** The episode number that just aired */
  withEpisode() {
    query[0] = query[0].set({ subField: "episode", level })
    return this
  },
  /** The notification context text */
  withContexts() {
    query[0] = query[0].set({ subField: "contexts", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The associated media of the airing schedule */
  withMedia(fn: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

const FollowingNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the user who followed the authenticated user */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The liked activity */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const ActivityMessageNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The if of the user who send the message */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the activity message */
  withActivityId() {
    query[0] = query[0].set({ subField: "activityId", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The message activity */
  withMessage(fn?: Fn<typeof MessageActivity>) {
    query[0] = query[0].set({ subField: "message", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(MessageActivity({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MessageActivity({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who sent the message */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const ActivityNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the user who mentioned the authenticated user */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the activity where mentioned */
  withActivityId() {
    query[0] = query[0].set({ subField: "activityId", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The liked activity */
  withActivity(fn?: Fn<typeof ActivityUnion>) {
    query[0] = query[0].set({ subField: "activity", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(ActivityUnion({ query: tmpQuery = [query[0]], level: level + 1 }))
    else {
      ActivityUnion({ query: tmpQuery = [query[0]], level: level + 1 })
        .withListActivity()
        .withMessageActivity()
        .withTextActivity()
    }
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who mentioned the authenticated user */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const ThreadCommentNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the user who mentioned the authenticated user */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the comment where mentioned */
  withCommentId() {
    query[0] = query[0].set({ subField: "commentId", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The thread that the relevant comment belongs to */
  withThread(fn?: Fn<typeof Thread>) {
    query[0] = query[0].set({ subField: "thread", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Thread({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Thread({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The thread comment that included the @ mention */
  withComment(fn?: Fn<typeof ThreadComment>) {
    query[0] = query[0].set({ subField: "comment", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who mentioned the authenticated user */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const ThreadLikeNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the user who liked to the activity */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the thread which was liked */
  withThreadId() {
    query[0] = query[0].set({ subField: "threadId", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The thread that the relevant comment belongs to */
  withThread(fn?: Fn<typeof Thread>) {
    query[0] = query[0].set({ subField: "thread", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Thread({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Thread({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The liked thread comment */
  withComment(fn?: Fn<typeof ThreadComment>) {
    query[0] = query[0].set({ subField: "comment", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who liked the activity */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const RelatedMediaAdditionNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the new media */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  /** The notification context text */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The associated media of the airing schedule */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const MediaDataChangeNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the media that received data changes */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  /** The reason for the media data change */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The reason for the media data change */
  withReason() {
    query[0] = query[0].set({ subField: "reason", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The media that received data changes */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const MediaMergeNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The id of the media that was merged into */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaId", level })
    return this
  },
  /** The title of the deleted media */
  withDeletedMediaTitles() {
    query[0] = query[0].set({ subField: "deletedMediaTitles", level })
    return this
  },
  /** The reason for the media data change */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The reason for the media merge */
  withReason() {
    query[0] = query[0].set({ subField: "reason", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The media that was merged into */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

const MediaDeletionNotification = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the Notification */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The type of notification */
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
  /** The title of the deleted media */
  withDeletedMediaTitle() {
    query[0] = query[0].set({ subField: "deletedMediaTitle", level })
    return this
  },
  /** The reason for the media deletion */
  withContext() {
    query[0] = query[0].set({ subField: "context", level })
    return this
  },
  /** The reason for the media deletion */
  withReason() {
    query[0] = query[0].set({ subField: "reason", level })
    return this
  },
  /** The time the notification was created at */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
})

export const NotificationUnion = ({ query, level }: Fields<UpdateOperation>) => ({
  AiringNotification(fn?: Fn<typeof AiringNotification>) {
    query[0] = query[0].set({
      subField: "AiringNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(AiringNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else AiringNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  FollowingNotification(fn?: Fn<typeof FollowingNotification>) {
    query[0] = query[0].set({
      subField: "FollowingNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(FollowingNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else FollowingNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityMessageNotification(fn?: Fn<typeof ActivityMessageNotification>) {
    query[0] = query[0].set({
      subField: "ActivityMessageNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityMessageNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityMessageNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityMentionNotification(fn?: Fn<typeof ActivityNotification>) {
    query[0] = query[0].set({
      subField: "ActivityMentionNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityReplyNotification(fn?: Fn<typeof ActivityNotification>) {
    query[0] = query[0].set({
      subField: "ActivityReplyNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityReplySubscribedNotification(fn?: Fn<typeof ActivityNotification>) {
    query[0] = query[0].set({
      subField: "ActivityReplySubscribedNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityLikeNotification(fn?: Fn<typeof ActivityNotification>) {
    query[0] = query[0].set({
      subField: "ActivityLikeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ActivityReplyLikeNotification(fn?: Fn<typeof ActivityNotification>) {
    query[0] = query[0].set({
      subField: "ActivityReplyLikeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ThreadCommentMentionNotification(fn?: Fn<typeof ThreadCommentNotification>) {
    query[0] = query[0].set({
      subField: "ThreadCommentMentionNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ThreadCommentReplyNotification(fn?: Fn<typeof ThreadCommentNotification>) {
    query[0] = query[0].set({
      subField: "ThreadCommentReplyNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ThreadCommentSubscribedNotification(fn?: Fn<typeof ThreadCommentNotification>) {
    query[0] = query[0].set({
      subField: "ThreadCommentSubscribedNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ThreadCommentLikeNotification(fn?: Fn<typeof ThreadCommentNotification>) {
    query[0] = query[0].set({
      subField: "ThreadCommentLikeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadCommentNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  ThreadLikeNotification(fn?: Fn<typeof ThreadLikeNotification>) {
    query[0] = query[0].set({
      subField: "ThreadLikeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(ThreadLikeNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadLikeNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  RelatedMediaAdditionNotification(fn?: Fn<typeof RelatedMediaAdditionNotification>) {
    query[0] = query[0].set({
      subField: "RelatedMediaAdditionNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(RelatedMediaAdditionNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else {RelatedMediaAdditionNotification({ query: tmpQuery = [query[0]], level: level + 1 })
        .withId()}
    query[0] = tmpQuery[0]
    return this
  },
  MediaDataChangeNotification(fn?: Fn<typeof MediaDataChangeNotification>) {
    query[0] = query[0].set({
      subField: "MediaDataChangeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(MediaDataChangeNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaDataChangeNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  MediaMergeNotification(fn?: Fn<typeof MediaMergeNotification>) {
    query[0] = query[0].set({
      subField: "MediaMergeNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(MediaMergeNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaMergeNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  MediaDeletionNotification(fn?: Fn<typeof MediaDeletionNotification>) {
    query[0] = query[0].set({
      subField: "MediaDeletionNotification",
      level,
      hasSubField: true,
      isUnion: true,
    })
    let tmpQuery
    if (fn) fn(MediaDeletionNotification({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaDeletionNotification({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
