import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { AtLeastOne } from "../types/AtLeastOne.ts"
import {
  PageActivitiesArgs,
  PageActivityRepliesArgs,
  PageAiringSchedulesArgs,
  PageCharactersArgs,
  PageFollowersArgs,
  PageFollowingArgs,
  //   PageInfo,
  PageLikesArgs,
  PageMediaArgs,
  PageMediaListArgs,
  PageMediaTrendsArgs,
  PageNotificationsArgs,
  PageRecommendationsArgs,
  PageReviewsArgs,
  PageStaffArgs,
  PageStudiosArgs,
  PageThreadCommentsArgs,
  PageThreadsArgs,
  PageUsersArgs,
} from "../types/generated/graphql.ts"
import { ActivityReply } from "./ActivityReply.ts"
import { ActivityUnion } from "./ActivityUnion.ts"
import { AiringSchedule } from "./AiringSchedule.ts"
import { Character } from "./Character.ts"
import { Media } from "./Media.ts"
import { MediaList } from "./MediaList.ts"
import { MediaTrend } from "./MediaTrend.ts"
import { NotificationUnion } from "./NotificationUnion.ts"
import { Recommendation } from "./Recommendation.ts"
import { Review } from "./Review.ts"
import { Staff } from "./Staff.ts"
import { Studio } from "./Studio.ts"
import { Thread } from "./Thread.ts"
import { ThreadComment } from "./ThreadComment.ts"
import { User } from "./User.ts"

export const PageInfo = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The total number of items. Note: This value is not guaranteed to be accurate, do not rely on this for logic */
  withTotal() {
    query[0] = query[0].set({ subField: "total", level })
    return this
  },
  /** The count on a page */
  withPerPage() {
    query[0] = query[0].set({ subField: "perPage", level })
    return this
  },
  /** The current page */
  withCurrentPage() {
    query[0] = query[0].set({ subField: "currentPage", level })
    return this
  },
  /** The last page */
  withLastPage() {
    query[0] = query[0].set({ subField: "lastPage", level })
    return this
  },
  /** If there is another page */
  withHasNextPage() {
    query[0] = query[0].set({ subField: "hasNextPage", level })
    return this
  },
})

export const Page = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withUsers(op?: { args?: AtLeastOne<PageUsersArgs>; fn?: Fn<typeof User> }) {
    query[0] = query[0].set({ subField: "users", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withMedia(op?: { args?: AtLeastOne<PageMediaArgs>; fn?: Fn<typeof Media> }) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withCharacters(op?: { args?: AtLeastOne<PageCharactersArgs>; fn?: Fn<typeof Character> }) {
    query[0] = query[0].set({
      subField: "characters",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(Character({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Character({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withStaff(op?: { args?: AtLeastOne<PageStaffArgs>; fn?: Fn<typeof Staff> }) {
    query[0] = query[0].set({ subField: "staff", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Staff({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withStudios(op?: { args?: AtLeastOne<PageStudiosArgs>; fn?: Fn<typeof Studio> }) {
    query[0] = query[0].set({ subField: "studios", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(Studio({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Studio({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withMediaList(op?: { args?: AtLeastOne<PageMediaListArgs>; fn?: Fn<typeof MediaList> }) {
    query[0] = query[0].set({
      subField: "mediaList",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(MediaList({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaList({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withAiringSchedules(
    op?: { args?: AtLeastOne<PageAiringSchedulesArgs>; fn?: Fn<typeof AiringSchedule> },
  ) {
    query[0] = query[0].set({
      subField: "airingSchedules",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }))
    else AiringSchedule({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withMediaTrends(op?: { args?: AtLeastOne<PageMediaTrendsArgs>; fn?: Fn<typeof MediaTrend> }) {
    query[0] = query[0].set({
      subField: "mediaTrends",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }))
    else MediaTrend({ query: tmpQuery = [query[0]], level: level + 1 }).withMediaId()
    query[0] = tmpQuery[0]
    return this
  },
  withNotifications(
    op: { args?: AtLeastOne<PageNotificationsArgs>; fn: Fn<typeof NotificationUnion> },
  ) {
    query[0] = query[0].set({
      subField: "notifications",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    op.fn(NotificationUnion({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withFollowers(op?: { args?: AtLeastOne<PageFollowersArgs>; fn?: Fn<typeof User> }) {
    query[0] = query[0].set({
      subField: "followers",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withFollowing(op?: { args?: AtLeastOne<PageFollowingArgs>; fn?: Fn<typeof User> }) {
    query[0] = query[0].set({
      subField: "following",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withActivities(op?: { args?: AtLeastOne<PageActivitiesArgs>; fn?: Fn<typeof ActivityUnion> }) {
    query[0] = query[0].set({
      subField: "activities",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(ActivityUnion({ query: tmpQuery = [query[0]], level: level + 1 }))
    else {
      ActivityUnion({ query: tmpQuery = [query[0]], level: level + 1 })
        .withListActivity()
        .withMessageActivity()
        .withTextActivity()
    }
    query[0] = tmpQuery[0]
    return this
  },
  withActivityReplies(
    op?: { args?: AtLeastOne<PageActivityRepliesArgs>; fn?: Fn<typeof ActivityReply> },
  ) {
    query[0] = query[0].set({
      subField: "activityReplies",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ActivityReply({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withThreads(op?: { args?: AtLeastOne<PageThreadsArgs>; fn?: Fn<typeof Thread> }) {
    query[0] = query[0].set({ subField: "threads", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(Thread({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Thread({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withThreadComments(
    op?: { args?: AtLeastOne<PageThreadCommentsArgs>; fn?: Fn<typeof ThreadComment> },
  ) {
    query[0] = query[0].set({
      subField: "threadComments",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ThreadComment({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withReviews(op?: { args?: AtLeastOne<PageReviewsArgs>; fn?: Fn<typeof Review> }) {
    query[0] = query[0].set({ subField: "reviews", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(Review({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Review({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withRecommendations(
    op?: { args?: AtLeastOne<PageRecommendationsArgs>; fn?: Fn<typeof Recommendation> },
  ) {
    query[0] = query[0].set({
      subField: "recommendations",
      level,
      hasSubField: true,
      variables: op?.args,
    })
    let tmpQuery
    if (op?.fn) op.fn(Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  withLikes(op?: { args?: AtLeastOne<PageLikesArgs>; fn?: Fn<typeof User> }) {
    query[0] = query[0].set({ subField: "likes", level, hasSubField: true, variables: op?.args })
    let tmpQuery
    if (op?.fn) op.fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
