import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { User } from "./User.ts"
import { PageInfo } from "./Page.ts"

const RecommendationEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn?: Fn<typeof Recommendation>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
export const RecommendationConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn?: Fn<typeof RecommendationEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(RecommendationEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    else RecommendationEdge({ query: tmpQuery = [query[0]], level: level + 1 }).withNode()
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn?: Fn<typeof Recommendation>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Recommendation({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const Recommendation = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the recommendation */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** Users rating of the recommendation */
  withRating() {
    query[0] = query[0].set({ subField: "rating", level })
    return this
  },
  /** The rating of the recommendation by currently authenticated user */
  withUserRating() {
    query[0] = query[0].set({ subField: "userRating", level })
    return this
  },
  /** The media the recommendation is from */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The recommended media */
  withMediaRecommendation(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user that first created the recommendation */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
