import { PageInfo } from "./Page.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { User } from "./User.ts"

const ReviewEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn?: Fn<typeof Review>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Review({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Review({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})

export const ReviewConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn?: Fn<typeof ReviewEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(ReviewEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    else ReviewEdge({ query: tmpQuery = [query[0]], level: level + 1 }).withNode()
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn?: Fn<typeof Review>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Review({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Review({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const Review = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the review */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The id of the review's creator */
  withUserId() {
    query[0] = query[0].set({ subField: "userid", level })
    return this
  },
  /** The id of the review's media */
  withMediaId() {
    query[0] = query[0].set({ subField: "mediaid", level })
    return this
  },
  /** For which type of media the review is for */
  withMediaType() {
    query[0] = query[0].set({ subField: "mediatype", level })
    return this
  },
  /** A short summary of the review */
  withSummary() {
    query[0] = query[0].set({ subField: "summary", level })
    return this
  },
  /** The main review body text */
  body(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "(args", level, variables: args })
    return this
  },
  /** The total user rating of the review */
  withRating() {
    query[0] = query[0].set({ subField: "rating", level })
    return this
  },
  /** The amount of user ratings of the review */
  withRatingAmount() {
    query[0] = query[0].set({ subField: "ratingamount", level })
    return this
  },
  /** The rating of the review by currently authenticated user */
  withUserRating() {
    query[0] = query[0].set({ subField: "userrating", level })
    return this
  },
  /** The review score of the media */
  withScore() {
    query[0] = query[0].set({ subField: "score", level })
    return this
  },
  /** If the review is not yet publicly published and is only viewable by creator */
  withPrivate() {
    query[0] = query[0].set({ subField: "private", level })
    return this
  },
  /** The url for the review page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteurl", level })
    return this
  },
  /** The time of the thread creation */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdat", level })
    return this
  },
  /** The time of the thread last update */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedat", level })
    return this
  },
  /** The creator of the review */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The media the review is of */
  withMedia(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "media", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
