import { StudioMediaArgs } from "../types/generated/graphql.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { PageInfo } from "./Page.ts"
import { MediaConnection } from "./Media.ts"
import { AtLeastOne } from "../types/AtLeastOne.ts"

const StudioEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn?: Fn<typeof Studio>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Studio({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Studio({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The id of the connection */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** If the studio is the main animation studio of the anime */
  withIsMain() {
    query[0] = query[0].set({ subField: "isMain", level })
    return this
  },
  /** The order the character should be displayed from the users favourites */
  withFavouriteOrder() {
    query[0] = query[0].set({ subField: "favouriteOrder", level })
    return this
  },
})

export const StudioConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn?: Fn<typeof StudioEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(StudioEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    else StudioEdge({ query: tmpQuery = [query[0]], level: level + 1 }).withNode()
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn?: Fn<typeof Studio>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Studio({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Studio({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const Studio = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the studio */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The name of the studio */
  withName() {
    query[0] = query[0].set({ subField: "name", level })
    return this
  },
  /** If the studio is an animation studio or a different kind of company */
  withIsAnimationStudio() {
    query[0] = query[0].set({ subField: "isAnimationStudio", level })
    return this
  },
  /** The media the studio has worked on */
  withMedia(op: { args?: AtLeastOne<StudioMediaArgs>; fn: Fn<typeof MediaConnection> }) {
    query[0] = query[0].set({ subField: "media", level, variables: op?.args, hasSubField: true })
    let tmpQuery
    op.fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The url for the studio page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** If the studio is marked as favourite by the currently authenticated user */
  withIsFavourite() {
    query[0] = query[0].set({ subField: "isFavourite", level })
    return this
  },
  /** The amount of user's who have favourited the studio */
  withFavourites() {
    query[0] = query[0].set({ subField: "favourites", level })
    return this
  },
})
