import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Media } from "./Media.ts"
import { User } from "./User.ts"

const ThreadCategory = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the category */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The name of the category */
  withName() {
    query[0] = query[0].set({ subField: "name", level })
    return this
  },
})

export const Thread = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the thread */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The title of the thread */
  withTitle() {
    query[0] = query[0].set({ subField: "title", level })
    return this
  },
  /** The text body of the thread (Markdown) */
  withBody(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "body", level, variables: args })
    return this
  },
  /** The id of the thread owner user */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The id of the user who most recently commented on the thread */
  withReplyUserId() {
    query[0] = query[0].set({ subField: "replyUserId", level })
    return this
  },
  /** The id of the most recent comment on the thread */
  withReplyCommentId() {
    query[0] = query[0].set({ subField: "replyCommentId", level })
    return this
  },
  /** The number of comments on the thread */
  withReplyCount() {
    query[0] = query[0].set({ subField: "replyCount", level })
    return this
  },
  /** The number of times users have viewed the thread */
  withViewCount() {
    query[0] = query[0].set({ subField: "viewCount", level })
    return this
  },
  /** If the thread is locked and can receive comments */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
  /** If the thread is stickied and should be displayed at the top of the page */
  withIsSticky() {
    query[0] = query[0].set({ subField: "isSticky", level })
    return this
  },
  /** If the currently authenticated user is subscribed to the thread */
  withIsSubscribed() {
    query[0] = query[0].set({ subField: "isSubscribed", level })
    return this
  },
  /** The amount of likes the thread has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the thread */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** The time of the last reply */
  withRepliedAt() {
    query[0] = query[0].set({ subField: "repliedAt", level })
    return this
  },
  /** The time of the thread creation */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The time of the thread last update */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
  /** The owner of the thread */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user to last reply to the thread */
  withReplyUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "replayUser", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the thread */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The url for the thread page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** The categories of the thread */
  withCategories(fn: Fn<typeof ThreadCategory>) {
    query[0] = query[0].set({ subField: "categories", level })
    let tmpQuery
    fn(ThreadCategory({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The media categories of the thread */
  withMediaCategories(fn?: Fn<typeof Media>) {
    query[0] = query[0].set({ subField: "mediaCategories", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Media({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Media({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
})
