import { User } from "./User.ts"
import { Thread } from "./Thread.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"

export const ThreadComment = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the comment */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The user id of the comment's owner */
  withUserId() {
    query[0] = query[0].set({ subField: "userId", level })
    return this
  },
  /** The id of thread the comment belongs to */
  withThreadId() {
    query[0] = query[0].set({ subField: "threadId", level })
    return this
  },
  /** The text content of the comment (Markdown) */
  withComment(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "comment", level, variables: args })
    return this
  },
  /** The amount of likes the comment has */
  withLikeCount() {
    query[0] = query[0].set({ subField: "likeCount", level })
    return this
  },
  /** If the currently authenticated user liked the comment */
  withIsLiked() {
    query[0] = query[0].set({ subField: "isLiked", level })
    return this
  },
  /** The url for the comment page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** The time of the comments creation */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** The time of the comments last update */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
  /** The thread the comment belongs to */
  withThread(fn?: Fn<typeof Thread>) {
    query[0] = query[0].set({ subField: "thread", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(Thread({ query: tmpQuery = [query[0]], level: level + 1 }))
    else Thread({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user who created the comment */
  withUser(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "user", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The users who liked the comment */
  withLikes(fn?: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "likes", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    else User({ query: tmpQuery = [query[0]], level: level + 1 }).withId()
    query[0] = tmpQuery[0]
    return this
  },
  /** The comment's child reply comments */
  withChildComments() {
    query[0] = query[0].set({ subField: "childComments", level })
    return this
  },
  /** If the comment tree is locked and may not receive replies or edits */
  withIsLocked() {
    query[0] = query[0].set({ subField: "isLocked", level })
    return this
  },
})
