import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { Favourites } from "./Favourites.ts"
import { MediaListOptions } from "./MediaList.ts"
import { UserStatisticTypes } from "./UserStatistics.ts"

const NotificationOption = ({ query, level }: Fields<UpdateOperation>) => ({
  withEnabled() {
    query[0] = query[0].set({ subField: "enabled", level })
    return this
  },
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
})

const ListActivityOption = ({ query, level }: Fields<UpdateOperation>) => ({
  withDisabled() {
    query[0] = query[0].set({ subField: "disabled", level })
    return this
  },
  withType() {
    query[0] = query[0].set({ subField: "type", level })
    return this
  },
})

export const UserPreviousName = ({ query, level }: Fields<UpdateOperation>) => ({
  /** A previous name of the user. */
  withName() {
    query[0] = query[0].set({ subField: "name", level })
    return this
  },
  /** When the user first changed from this name. */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /** When the user most recently changed from this name. */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
})

export const UserOptions = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The language the user wants to see media titles in */
  withTitleLanguage() {
    query[0] = query[0].set({ subField: "titleLanguage", level })
    return this
  },

  /** Whether the user has enabled viewing of 18+ content */
  withDisplayAdultContent() {
    query[0] = query[0].set({ subField: "displayAdultContent", level })
    return this
  },

  /** Whether the user receives notifications when a show they are watching aires */
  withAiringNotifications() {
    query[0] = query[0].set({ subField: "airingNotifications", level })
    return this
  },

  /** Profile highlight color (blue, purple, pink, orange, red, green, gray) */
  withProfileColor() {
    query[0] = query[0].set({ subField: "profileColor", level })
    return this
  },

  /** Notification options */
  withNotificationOptions(fn: Fn<typeof NotificationOption>) {
    query[0] = query[0].set({ subField: "notificationOptions", level })
    let tmpQuery
    fn(NotificationOption({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },

  /** The user's timezone offset (Auth user only) */
  withTimezone() {
    query[0] = query[0].set({ subField: "timezone", level })
    return this
  },

  /** Minutes between activity for them to be merged together. 0 is Never, Above 2 weeks (20160 mins) is Always. */
  withActivityMergeTime() {
    query[0] = query[0].set({ subField: "activityMergeTime", level })
    return this
  },

  /** The language the user wants to see staff and character names in */
  withStaffNameLanguage() {
    query[0] = query[0].set({ subField: "staffNameLanguage", level })
    return this
  },

  /** Whether the user only allow messages from users they follow */
  withRestrictMessagesToFollowing() {
    query[0] = query[0].set({ subField: "restrictMessagesToFollowing", level })
    return this
  },

  /** The list activity types the user has disabled from being created from list updates */
  withDisabledListActivity(fn: Fn<typeof ListActivityOption>) {
    query[0] = query[0].set({
      subField: "disabledListActivity",
      level,
      hasSubField: true,
    })
    let tmpQuery
    fn(ListActivityOption({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

export const UserAvatar = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The avatar of user at its largest size */
  withLarge() {
    query[0] = query[0].set({ subField: "large", level })
    return this
  },
  /** The avatar of user at medium size */
  withMedium() {
    query[0] = query[0].set({ subField: "medium", level })
    return this
  },
})

export const User = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The id of the user */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The name of the user */
  withName() {
    query[0] = query[0].set({ subField: "name", level })
    return this
  },
  /** The bio written by user (Markdown) */
  withAbout(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "about", level, variables: args })
    return this
  },
  /** The user's avatar images */
  withAvatar(fn?: Fn<typeof UserAvatar>) {
    query[0] = query[0].set({ subField: "avatar", level, hasSubField: true })
    let tmpQuery
    if (fn) fn(UserAvatar({ query: tmpQuery = [query[0]], level: level + 1 }))
    else UserAvatar({ query: tmpQuery = [query[0]], level: level + 1 }).withMedium()
    query[0] = tmpQuery[0]
    return this
  },
  /** The user's banner images */
  withBannerImage() {
    query[0] = query[0].set({ subField: "bannerImage", level })
    return this
  },
  /** If the authenticated user if following this user */
  withIsFollowing() {
    query[0] = query[0].set({ subField: "isFollowing", level })
    return this
  },
  /** If this user if following the authenticated user */
  withIsFollower() {
    query[0] = query[0].set({ subField: "isFollower", level })
    return this
  },
  /** If the user is blocked by the authenticated user */
  withIsBlocked() {
    query[0] = query[0].set({ subField: "isBlocked", level })
    return this
  },
  withBans() {
    query[0] = query[0].set({ subField: "bans", level })
    return this
  },
  /* The user's general options */
  withOptions(fn: Fn<typeof UserOptions>) {
    query[0] = query[0].set({ subField: "options", level })
    let tmpQuery
    fn(UserOptions({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /* The user's media list options */
  withMediaListOptions(fn: Fn<typeof MediaListOptions>) {
    query[0] = query[0].set({ subField: "mediaListOptions", level })
    let tmpQuery
    fn(MediaListOptions({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /* The users favourites */
  withFavourites(op: { args?: { page: number }; fn: Fn<typeof Favourites> }) {
    query[0] = query[0].set({ subField: "favourites", level, variables: op?.args })
    let tmpQuery
    op.fn(Favourites({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /* The users anime & manga list statistics */
  withStatistics(fn: Fn<typeof UserStatisticTypes>) {
    query[0] = query[0].set({ subField: "statistics", level, hasSubField: true })
    let tmpQuery
    fn(UserStatisticTypes({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /* The number of unread notifications the user has */
  withUnreadNotificationCount() {
    query[0] = query[0].set({ subField: "unreadNotificationCount", level })
    return this
  },
  /* The url for the user page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /* The donation tier of the user */
  withDonatorTier() {
    query[0] = query[0].set({ subField: "donatorTier", level })
    return this
  },
  /* Custom donation badge text */
  withDonatorBadge() {
    query[0] = query[0].set({ subField: "donatorBadge", level })
    return this
  },
  /* The user's moderator roles if they are a site moderator */
  withModeratorRoles() {
    query[0] = query[0].set({ subField: "moderatorRoles", level })
    return this
  },
  /* When the user's account was created. (Does not exist for accounts created before 2020) */
  withCreatedAt() {
    query[0] = query[0].set({ subField: "createdAt", level })
    return this
  },
  /* When the user's data was last updated */
  withUpdatedAt() {
    query[0] = query[0].set({ subField: "updatedAt", level })
    return this
  },
  /* The user's previously used names. */
  withPreviousNames(fn?: Fn<typeof UserPreviousName>) {
    query[0] = query[0].set({
      subField: "previousNames",
      level,
      hasSubField: true,
    })
    let tmpQuery
    if (fn) fn(UserPreviousName({ query: tmpQuery = [query[0]], level: level + 1 }))
    else UserPreviousName({ query: tmpQuery = [query[0]], level: level + 1 }).withName()
    query[0] = tmpQuery[0]
    return this
  },
})
