import { type AuthorizationError } from "../utils/AuthorizationError.ts"
import { ResponseError } from "../utils/ResponseError.ts"

export type Fields<in Q extends (...args: any) => any> = {
  query: ReturnType<Q>[]
  level: number
}
export type Fn<F extends (...args: any) => any> = (
  fields: ReturnType<F>,
) => void

export type Variables = { [arg: string]: string | number | boolean | string[] }

export type UpdateOperation = {
  (opts: {
    query?: string
    variables?: any
    fields: string[]
    level: number
    hasSubField?: true
    isUnion?: true
  }): {
    get(): string
    set(
      { subField, variables, hasSubField, level }:
        & Omit<Parameters<UpdateOperation>[0], "query" | "fields">
        & { subField: string },
    ): ReturnType<UpdateOperation>
  }
}

export type Authorization = {
  token_type: string
  expires_in: number
  access_token: string
  /** Currently not used for anything */
  refresh_token: string
}

export type Fetch = {
  (
    init:
      & Record<
        | "code"
        | "client_id"
        | "client_secret"
        | "redirect_uri",
        string
      >
      & { "grant_type"?: "authorization_code" },
  ): Promise<Authorization | AuthorizationError>
  (
    init: { query: string; token?: string },
  ): Promise<Response | ResponseError>
}
export type Response<T = Record<string, any>> = {
  data: T
}
